<?php

namespace Onestartup\ProductPrimerPlano\Controller;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Yajra\Datatables\Datatables;
use Onestartup\ProductPrimerPlano\Model\Product;
use Onestartup\ProductPrimerPlano\Model\ProductCategory as Category;
use Onestartup\ProductPrimerPlano\Model\ProductSubCategory as SubCategory;

class ProductController extends Controller
{
    public function index(Request $request)
    {
    	if(isset($request->category)){

            $category = Category::where('slug', $request->category)->first();
            $products = $category->products()->where('active', true)->paginate(config("product.product-index."));

        } else {
            $products = Product::where('active', true)->paginate(config("product.product-index.pagination"));
        }
        $otros = Product::where('active', true)->inRandomOrder()->take(config("product.product-index.otros"))->get();
        $categories = Category::where('active', true)->get();
        
        return view('product-public::list')
            ->with('categories', $categories)
            ->with('otros', $otros)
            ->with('products', $products);
        
    }

    public function show($slug)
    {

    	$product = Product::where('slug',$slug)->first();
        $categories = Category::all();

        if ($product != null) {
            if (!$product->active) {
               return redirect()->route("main.product")->with('inactivo', 'No esta disponible');
            }
        } else {
            return redirect()->route("main.product")->with('notFound', 'No existe');
        }

        $otros = $product->category->products()->where('active', true)->where("id", "<>", $product->id)->inRandomOrder()->take(config("product.product-show.otros"))->get(); 

        return view('product-public::single')
            ->with('product', $product)
            ->with('categories', $categories)
            ->with('otros', $otros);
        
    }

    public function byCategory($category_slug)
    {
        $category = Category::where('slug', $category_slug)->first();
        $products = $category->products()->where('active', true)->paginate(config("product.product-bycategory.pagination"));

        $otros = Product::where('active', true)->inRandomOrder()->take(config("product.product-bycategory.otros"))->get();
        $categories = Category::where('active', true)->get();
        
        return view('product-public::category')
            ->with('categories', $categories)
            ->with('otros', $otros)
            ->with('category', $category)
            ->with('products', $products);
        
    }
     public function bySubCategory($category_slug, $subcategory_slug)
    {
        //return $category_slug . " " .$subcategory_slug;
        $category = Category::where('slug', $category_slug)->first();
        $subcategory = $category->subcategories->where('slug', $subcategory_slug)->first();
        $products = $subcategory->products()->where('active', true)->paginate(config("product.product-bysubcategory.pagination"));

        $otros = Product::where('active', true)->inRandomOrder()->take(config("product.product-bycategory.otros"))->get();
        $categories = Category::where('active', true)->get();
        $subcategories = $category->subcategories()->where('active' ,true)->get();
        
        return view('product-public::subcategory')
            ->with('categories', $categories)
            ->with('subcategories', $subcategories)
            ->with('otros', $otros)
            ->with('category', $category)
            ->with('subcategory', $subcategory)
            ->with('products', $products);
        
    }

}
